@@ -9,8 +9,9 @@ from ..aussportsbetting.nfl_aussportsbetting_league_model import \
 from ..espn.nfl_espn_league_model import NFLESPNLeagueModel
 from ..oddsportal.nfl_oddsportal_league_model import NFLOddsPortalLeagueModel
 from ..sportsdb.nfl_sportsdb_league_model import NFLSportsDBLeagueModel
-from ..sportsreference.nfl_sportsreference_league_model import \
-    NFLSportsReferenceLeagueModel
+
+# from ..sportsreference.nfl_sportsreference_league_model import \
+#    NFLSportsReferenceLeagueModel
 
 LOS_ANGELES_RAMS = "135907"
 CHICAGO_BEARS = "134938"
@@ -387,7 +388,7 @@ class NFLCombinedLeagueModel(CombinedLeagueModel):
                 NFLSportsDBLeagueModel(session, position=1),
                 NFLAusSportsBettingLeagueModel(session, position=2),
                 NFLOddsPortalLeagueModel(session, position=3),
-                NFLSportsReferenceLeagueModel(session, position=4),
+                # NFLSportsReferenceLeagueModel(session, position=4),
             ],
             league_filter,
         )
