@@ -482,6 +482,18 @@ class TestCombinedTeamModel(unittest.TestCase):
                 dots=None,
                 wides=None,
                 no_balls=None,
+                free_throw_attempt_rate=None,
+                offensive_rebound_percentage=None,
+                defensive_rebound_percentage=None,
+                total_rebound_percentage=None,
+                assist_percentage=None,
+                steal_percentage=None,
+                block_percentage=None,
+                turnover_percentage=None,
+                usage_percentage=None,
+                offensive_rating=None,
+                defensive_rating=None,
+                box_plus_minus=None,
             )]
             team_models = [TeamModel(
                 identifier="a",
@@ -979,6 +991,18 @@ class TestCombinedTeamModel(unittest.TestCase):
                 dots=None,
                 wides=None,
                 no_balls=None,
+                free_throw_attempt_rate=None,
+                offensive_rebound_percentage=None,
+                defensive_rebound_percentage=None,
+                total_rebound_percentage=None,
+                assist_percentage=None,
+                steal_percentage=None,
+                block_percentage=None,
+                turnover_percentage=None,
+                usage_percentage=None,
+                offensive_rating=None,
+                defensive_rating=None,
+                box_plus_minus=None,
             )]
             team_models_2 = [TeamModel(
                 identifier="a",
@@ -1485,6 +1509,18 @@ class TestCombinedTeamModel(unittest.TestCase):
                 dots=None,
                 wides=None,
                 no_balls=None,
+                free_throw_attempt_rate=None,
+                offensive_rebound_percentage=None,
+                defensive_rebound_percentage=None,
+                total_rebound_percentage=None,
+                assist_percentage=None,
+                steal_percentage=None,
+                block_percentage=None,
+                turnover_percentage=None,
+                usage_percentage=None,
+                offensive_rating=None,
+                defensive_rating=None,
+                box_plus_minus=None,
             )]
             team_models = [TeamModel(
                 identifier="a",
@@ -1982,6 +2018,18 @@ class TestCombinedTeamModel(unittest.TestCase):
                 dots=None,
                 wides=None,
                 no_balls=None,
+                free_throw_attempt_rate=None,
+                offensive_rebound_percentage=None,
+                defensive_rebound_percentage=None,
+                total_rebound_percentage=None,
+                assist_percentage=None,
+                steal_percentage=None,
+                block_percentage=None,
+                turnover_percentage=None,
+                usage_percentage=None,
+                offensive_rating=None,
+                defensive_rating=None,
+                box_plus_minus=None,
             )]
             team_models_2 = [TeamModel(
                 identifier="a",
